@@ -1,5 +1,6 @@
 from pytest import raises
 
+from wonambi import Dataset
 from wonambi.attr.chan import create_sphere_around_elec
 from wonambi.attr import Freesurfer, Surf
 from wonambi.source import Morph
@@ -7,6 +8,8 @@ from wonambi.utils import create_data
 
 from .paths import (fs_path,
                     surf_path,
+                    eeglab_hdf5_1_file,
+                    hdf5_file,
                     )
 
 fs = Freesurfer(fs_path)
@@ -39,3 +42,11 @@ def test_import_morph():
 def test_scroll_data():
     with raises(ImportError):
         from wonambi.scroll_data import MainWindow
+
+
+def test_import_ioeeg():
+    with raises(ImportError):
+        Dataset(eeglab_hdf5_1_file)
+
+    with raises(ImportError):
+        Dataset(hdf5_file)
