@@ -17,7 +17,8 @@ def test_openephys_markers():
 
     assert len(markers) == 10
     assert markers[0]['name'] == 'START RECORDING #0'
-    assert markers[7]['end'] == 95.402
+    assert markers[7]['name'] == '5'
+    assert markers[7]['end'] == 110.762
     assert markers[-1]['name'] == 'END RECORDING #1'
 
 
@@ -27,8 +28,7 @@ def test_openephys_header():
 
     assert start_time.second == 50
     assert len(chan_name) == 19  # some channels were deleted on purpose
-    assert n_samples == 262656
-
+    assert n_samples == 312832
 
 def test_openephys_read():
     self = OpenEphys(filename, session=2)
@@ -36,17 +36,17 @@ def test_openephys_read():
     mrks = self.return_markers()
 
     # before beginning
-    dat = self.return_dat([0, ], -20, -10)
+    dat = self.return_dat([0, ], -20 + self.first_timestamp, -10 + self.first_timestamp)
     assert isnan(dat[0, :]).all()
 
     # beginning
-    dat = self.return_dat([0, ], -5, 5)
+    dat = self.return_dat([0, ], -5 + self.first_timestamp, 5 + self.first_timestamp)
     assert isnan(dat[0, :5]).all()
     assert not isnan(dat[0, 5:]).any()
 
     # values
-    dat = self.return_dat([0, ], 1020, 1030)
-    assert dat[0, :].sum() == -19438.575
+    dat = self.return_dat([0, ], 60020, 60030)
+    assert dat[0, :].sum() == 49366.2
 
     # end of first segment
     start_seg = [x['start'] for x in mrks if x['name'] == 'END RECORDING #0' ][0]
