@@ -1,5 +1,5 @@
 from pytest import raises
-from wonambi.utils import create_data
+from wonambi.utils import create_data, create_channels
 
 
 def test_import():
@@ -22,8 +22,9 @@ def test_simulate_02():
 
 def test_simulate_03():
     N_TRIAL = 10
-    data = create_data(n_trial=N_TRIAL)
+    data = create_data(n_trial=N_TRIAL, chan_name=['chan0', 'chan2'])
     assert data.data.shape[0] == N_TRIAL
+    assert data.data[0].shape[0] == 2
 
 
 def test_simulate_04():
@@ -51,3 +52,18 @@ def test_simulate_07():
     data = create_data(datatype='ChanFreq', freq=FREQ_LIMITS)
     assert data.axis['freq'][0][0] == FREQ_LIMITS[0]
     assert data.axis['freq'][0][-1] < FREQ_LIMITS[1]
+
+
+def test_simulate_channels_00():
+    data = create_data(attr=['chan', ])
+    assert 'chan' in data.attr
+
+
+def test_simulate_channels_01():
+    with raises(TypeError):
+        create_channels()
+
+def test_simulate_channels_02():
+    N_CHAN = 13
+    chans = create_channels(n_chan=N_CHAN)
+    assert len(chans.return_label()) == N_CHAN
