@@ -41,6 +41,7 @@ REMLOGIC_STAGE_KEY = {'SLEEP-S0': 'Wake',
                       'SLEEP-S1': 'NREM1',
                       'SLEEP-S2': 'NREM2',
                       'SLEEP-S3': 'NREM3',
+                      'SLEEP-S4': 'NREM3',
                       'SLEEP-REM': 'REM',
                       'SLEEP-UNSCORED': 'Undefined'}
 
@@ -383,6 +384,7 @@ class Annotations():
             return
         clue = None # used in some instances to pick out epochs from other evts
         idx_clue = None
+        redherring = None
             
         if source in ['remlogic', 'sandman']:
             encoding = 'ISO-8859-1'
@@ -424,10 +426,13 @@ class Annotations():
 
         elif source == 'remlogic':
             clue = 'SLEEP-' # signifies an epoch (as opposed to an event)
+            redherring = 'SPINDLE'
             idx_clue = slice(-18, -6)            
             idx_head = lines.index(
                     next(l for l in lines if 'Time [hh:mm:ss]' in l))
-            first_line = next(l for l in lines[idx_head:] if clue in l)
+            first_line = next(l for l in lines[idx_head:] \
+                              if clue in l[idx_clue] \
+                              and 'SLEEP-RM' not in l[-18:])
             idx_first_line = lines.index(first_line)
             
             stage_start_date = _try_parse_datetime(
@@ -610,6 +615,9 @@ class Annotations():
                 if clue is not None:
                     if clue not in one_line[idx_clue]:
                         continue
+                if redherring is not None:
+                    if redherring in one_line:
+                        continue
                 
                 epoch = SubElement(stages, 'epoch')
 
@@ -858,13 +866,12 @@ class Annotations():
         event_list : list of dict
             each dict is an event with 'start' and 'end' times
         name : str, optional
-            save events to this event type. If None, channel will be
-            read from the event list dict under 'name' 
+            save events to this event type. 
         chan : str or list of str, optional
             save events to this or these channel(s). If None, channel will be
             read from the event list dict under 'chan'        
         """
-        if name not in self.event_types:
+        if name is not None and name not in self.event_types:
             self.add_event_type(name)
 
         events = self.rater.find('events')
@@ -887,7 +894,7 @@ class Annotations():
             if chan is None:
                 one_chan = evt['chan']
             if isinstance(one_chan, (tuple, list)):
-                one_chan = ', '.join(chan)
+                one_chan = ', '.join(one_chan)
             event_chan = SubElement(new_event, 'event_chan')
             event_chan.text = one_chan
     
