@@ -74,7 +74,7 @@ class DetectSpindle:
 
         elif method == 'Moelle2011':
             if self.frequency is None:
-                self.frequency = (9, 15)
+                self.frequency = (12, 15)
             self.rolloff = 1.7
             self.det_remez = {'freq': self.frequency,
                               'rolloff': self.rolloff,
@@ -91,8 +91,9 @@ class DetectSpindle:
             if self.frequency is None:
                 self.frequency = (12, 15)
             self.det_wavelet = {'f0': mean(self.frequency),
-                                'sd': .5,
-                                'dur': 2,
+                                'sd': .8,
+                                'dur': 1.,
+                                'output': 'complex'
                                 }
             self.duration = (0.3, 3)
             self.smooth = {'dur': .1,
@@ -373,25 +374,21 @@ def detect_Lacourse2018(dat_orig, s_freq, time, opts):
     ----------
     Lacourse, K. et al. J. Neurosci. Meth. (2018).
     """
-    # Downsample z-score parameters, tolerance
+    # Prepare downsampling
     step = opts.windowing['step']
     if step:
         ds_freq = int(1 / step) # downsampled sampling frequency
-        opts.zscore['dur'] *= opts.windowing['step']
-        opts.tolerance *= opts.windowing['step']
-        if opts.zscore['step']:
-            opts.zscore['step'] *= opts.windowing['step']
+        opts.tolerance *= step
     else:
         ds_freq = s_freq
-
     
     # Absolute sigma power
     dat_sigma = transform_signal(dat_orig, s_freq, 'double_sosbutter', 
                                  opts.det_butter)
     dat_det = transform_signal(dat_sigma, s_freq, 'moving_ms', opts.moving_ms)
-    dat_det[dat_det <= 0] = 0.000000001
+    dat_det[dat_det <= 0] = 0.000000001 # arbitrarily small value
     abs_sig_pow = log10(dat_det)
-    # Option to adapt the absolute threshold, for low-amplitude recordings
+        # Option to adapt the absolute threshold, for low-amplitude recordings
     if opts.abs_pow_thresh < 0:
         opts.abs_pow_thresh = (mean(abs_sig_pow) - 
                                opts.abs_pow_thresh * std(abs_sig_pow))
@@ -402,7 +399,7 @@ def detect_Lacourse2018(dat_orig, s_freq, time, opts):
                                opts.moving_power_ratio)
     dat_det[dat_det <= 0] = 0.000000001
     dat_det = log10(dat_det)
-    rel_sig_pow = transform_signal(dat_det, s_freq, 'moving_zscore', 
+    rel_sig_pow = transform_signal(dat_det, ds_freq, 'moving_zscore', 
                                    opts.zscore)
     rel_sig_pow = transform_signal(rel_sig_pow, ds_freq, 'smooth', opts.smooth)
     
@@ -414,7 +411,7 @@ def detect_Lacourse2018(dat_orig, s_freq, time, opts):
     dat_det = dat_covar.copy()
     dat_det[dat_det < 0] = 0 # negative covariances are discarded
     dat_det = log10(dat_det + 1) # add 1 to avoid -inf
-    sigma_covar = transform_signal(dat_det, s_freq, 'moving_zscore', 
+    sigma_covar = transform_signal(dat_det, ds_freq, 'moving_zscore', 
                                    opts.zscore)
     sigma_covar = transform_signal(sigma_covar, ds_freq, 'smooth', opts.smooth)
     
@@ -438,10 +435,10 @@ def detect_Lacourse2018(dat_orig, s_freq, time, opts):
     
     if events is not None:
         events = _merge_close(dat_sigma, events, time, opts.tolerance)
-        events = _select_period(events, abs_and_cov)
+        events = _select_period(events, abs_and_cov) + 1
         
-        if opts.windowing['step']:
-            events = events * (s_freq * opts.windowing['step']) # upsample
+        if step:
+            events = events * (s_freq * step) # upsample
             events = asarray(around(events), dtype=int)
         
         events = within_duration(events, time, opts.duration)
@@ -639,8 +636,8 @@ def detect_Wamsley2012(dat_orig, s_freq, time, opts):
     ----------
     Wamsley, E. J. et al. Biol. Psychiatry 71, 154-61 (2012).
     """
-    dat_det = transform_signal(dat_orig, s_freq, 'morlet', opts.det_wavelet)
-    dat_det = real(dat_det ** 2) ** 2
+    dat_wav = transform_signal(dat_orig, s_freq, 'morlet', opts.det_wavelet)
+    dat_det = real(dat_wav ** 2) ** 2
     dat_det = transform_signal(dat_det, s_freq, 'smooth', opts.smooth)
 
     det_value = define_threshold(dat_det, s_freq, 'mean', opts.det_thresh)
@@ -655,8 +652,8 @@ def detect_Wamsley2012(dat_orig, s_freq, time, opts):
 
         power_peaks = peak_in_power(events, dat_orig, s_freq, opts.power_peaks)
         powers = power_in_band(events, dat_orig, s_freq, opts.frequency)
-        sp_in_chan = make_spindles(events, power_peaks, powers, dat_det,
-                                   dat_orig, time, s_freq)
+        sp_in_chan = make_spindles(events, power_peaks, powers, 
+                                   absolute(dat_wav), dat_orig, time, s_freq)
 
     else:
         lg.info('No spindle found')
@@ -794,21 +791,24 @@ def detect_Ferrarelli2007(dat_orig, s_freq, time, opts):
     dat_det = transform_signal(dat_det, s_freq, 'abs')
     
     idx_env = peaks_in_time(dat_det)
-    idx_peak = idx_env[peaks_in_time(dat_det[idx_env])]
+    envelope = dat_det[idx_env]
+    idx_peak = idx_env[peaks_in_time(envelope)] # in raw data time
+    idx_trough = peaks_in_time(envelope, troughs=True) # in envelope time
+    troughs = ones(len(envelope)) * -1
+    troughs[idx_trough] = envelope[idx_trough] # all non-trough values are -1
 
     det_value = define_threshold(dat_det, s_freq, 'mean', opts.det_thresh)
     sel_value = define_threshold(dat_det[idx_peak], s_freq, 'histmax', 
                                  opts.sel_thresh, nbins=120)
     
-    events_env = detect_events(dat_det[idx_env], 'above_thresh', det_value)
+    events_env = detect_events(envelope, 'above_thresh', det_value)
     
     if events_env is not None:
-        events_env = _merge_close(dat_det[idx_env], events_env, time[idx_env], 
+        events_env = _merge_close(envelope, events_env, time[idx_env], 
                                   opts.tolerance)
-        events_env = select_events(dat_det[idx_env], events_env, 
-                                   'above_thresh', sel_value)  
+        events_env = select_events(troughs, events_env, 
+                                   'Ferrarelli2007', sel_value)  
         events = idx_env[events_env]
-
         # merging is necessary, because detected spindles may overlap if the
         # signal envelope does not dip below sel_thresh between two peaks above 
         # det_thresh
@@ -1325,9 +1325,12 @@ def transform_signal(dat, s_freq, method, method_opt=None, dat2=None):
         f0 = method_opt['f0']
         sd = method_opt['sd']
         dur = method_opt['dur']
+        output = method_opt['output']
 
         wm = _wmorlet(f0, sd, s_freq, dur)
-        dat = absolute(fftconvolve(dat, wm, mode='same'))
+        dat = fftconvolve(dat, wm, mode='same')
+        if 'absolute' == output:
+            dat = absolute(dat)            
 
     if 'moving' in method:
         dur = method_opt['dur']
@@ -1345,7 +1348,7 @@ def transform_signal(dat, s_freq, method, method_opt=None, dat2=None):
         out = zeros((len_out))
         
         if 'moving_covar' == method:            
-            for i, j in enumerate(arange(0, total_dur, step)[:-2]):
+            for i, j in enumerate(arange(0, total_dur, step)[:-1]):
                 beg = max(0, int((j - halfdur) * s_freq))
                 end = min(last, int((j + halfdur) * s_freq))
                 win1 = dat[beg:end]
@@ -1359,7 +1362,7 @@ def transform_signal(dat, s_freq, method, method_opt=None, dat2=None):
             fft_dur = method_opt['fft_dur']
             nfft = int(s_freq * fft_dur)
             
-            for i, j in enumerate(arange(0, total_dur, step)[:-2]):
+            for i, j in enumerate(arange(0, total_dur, step)[:-1]):
                 beg = max(0, int((j - halfdur) * s_freq))
                 end = min(last, int((j + halfdur) * s_freq))
                 windat = dat[beg:end]
@@ -1379,7 +1382,7 @@ def transform_signal(dat, s_freq, method, method_opt=None, dat2=None):
             dat = out
         
         if 'moving_sd' == method:
-            for i, j in enumerate(arange(0, total_dur, step)[:-2]):
+            for i, j in enumerate(arange(0, total_dur, step)[:-1]):
                 beg = max(0, int((j - halfdur) * s_freq))
                 end = min(last, int((j + halfdur) * s_freq))
                 win = dat[beg:end]
@@ -1388,22 +1391,22 @@ def transform_signal(dat, s_freq, method, method_opt=None, dat2=None):
         
         if 'moving_zscore' == method:        
             pcl_range = method_opt['pcl_range']
+            if pcl_range is not None:
+                lo = percentile(dat, pcl_range[0])
+                hi = percentile(dat, pcl_range[1])
             
-            for i, j in enumerate(arange(0, total_dur, step)[:-2]):
+            for i, j in enumerate(arange(0, total_dur, step)[:-1]):
                 beg = max(0, int((j - halfdur) * s_freq))
                 end = min(last, int((j + halfdur) * s_freq))
                 windat = stddat = dat[beg:end]
                 
                 if pcl_range is not None:
-                    lo, hi = pcl_range
-                    stddat = windat[logical_and(
-                                            windat > percentile(windat, lo),
-                                            windat < percentile(windat, hi))]
+                    stddat = windat[logical_and(windat > lo, windat < hi)]
                 out[i] = (dat[i] - mean(windat)) / std(stddat)
             dat = out
         
         if method in ['moving_rms', 'moving_ms']:
-            for i, j in enumerate(arange(0, total_dur, step)[:-2]):
+            for i, j in enumerate(arange(0, total_dur, step)[:-1]):
                 beg = max(0, int((j - halfdur) * s_freq))
                 end = min(last, int((j + halfdur) * s_freq))
                 out[i] = mean(square(dat[beg:end]))   
@@ -1550,7 +1553,7 @@ def peaks_in_time(dat, troughs=False):
     
     target = -1 if not troughs else 1
         
-    return where(flipping == target)[0]
+    return where(flipping == target)[0] + 1
 
 
 def detect_events(dat, method, value=None):
@@ -1629,7 +1632,7 @@ def select_events(dat, detected, method, value):
     detected : ndarray (dtype='int')
         N x 3 matrix with start, peak, end samples
     method : str
-        'above_thresh', 'below_thresh'
+        'above_thresh', 'below_thresh', 'below_thresh_positive'
     value : float
         for 'threshold', it's the value of threshold for the spindle selection.
 
@@ -1645,7 +1648,12 @@ def select_events(dat, detected, method, value):
     elif method == 'below_thresh':
         below_sel = dat <= value
         detected = _select_period(detected, below_sel)
-
+    elif method == 'Ferrarelli2007':
+        below_sel = dat <= value
+        positive = dat >= 0
+        below_sel_positive = invert(logical_and(below_sel, positive))
+        detected = _select_period(detected, below_sel_positive)
+    
     return detected
 
 
