@@ -4,8 +4,8 @@ from copy import deepcopy
 from logging import getLogger
 from warnings import warn
 
-from numpy import (arange, array, asarray, copy, empty, exp, max, mean, pi,
-                   real, sqrt, swapaxes, zeros)
+from numpy import (arange, array, asarray, copy, empty, exp, log, max, mean, 
+                   median, pi, real, sqrt, swapaxes, zeros)
 from numpy.linalg import norm
 import numpy.fft as np_fft
 from scipy import fftpack
@@ -21,7 +21,8 @@ lg = getLogger(__name__)
 
 def frequency(data, output='spectraldensity', scaling='power', sides='one',
               taper=None, halfbandwidth=3, NW=None, duration=None,
-              overlap=0.5, step=None, detrend='linear', n_fft=None):
+              overlap=0.5, step=None, detrend='linear', n_fft=None,
+              log_trans=False, centend='mean'):
     """Compute the
     power spectral density (PSD, output='spectraldensity', scaling='power'), or
     energy spectral density (ESD, output='spectraldensity', scaling='energy') or
@@ -66,6 +67,12 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
         Length of FFT, in samples. If less than input axis, input is cropped.
         If longer than input axis, input is padded with zeros. If None, FFT
         length set to axis length.
+    log_trans : bool
+        If True, spectral values will be natural log-transformed. The
+        transformation is applied before averaging (or taking the median).
+    centend : str
+        (only if duration is not None). Central tendency measure to use, either
+        mean (arithmetic) or median.
 
     Returns
     -------
@@ -89,6 +96,9 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
 
     It uses sampling frequency as specified in s_freq, it does not
     recompute the sampling frequency based on the time axis.
+    
+    Use of log or median for Welch's method is included based on 
+    recommendations from Izhikevich et al., bioRxiv, 2018.
     """
     if output not in ('spectraldensity', 'complex', 'csd'):
         raise TypeError(f'output can be "spectraldensity", "complex" or "csd",'
@@ -138,8 +148,17 @@ def frequency(data, output='spectraldensity', scaling='power', sides='one',
                       NW=NW,
                       n_fft=n_fft)
 
+        if log_trans:
+            Sxx = log(Sxx)
+        
         if duration is not None:
-            Sxx = Sxx.mean(axis=-2)
+            if centend == 'mean':
+                Sxx = Sxx.mean(axis=-2)
+            elif centend == 'median':
+                Sxx = median(Sxx, axis=-2)
+            else:
+                raise ValueError('Invalid central tendency measure. '
+                                 'Use mean or median.')
 
         freq.axis['freq'][i] = f
         if output == 'complex':
@@ -324,7 +343,8 @@ def timefrequency(data, method='morlet', time_skip=1, **options):
     return timefreq
 
 
-def band_power(data, freq, scaling='power', n_fft=None, array_out=False):
+def band_power(data, freq, scaling='power', n_fft=None, detrend=None,
+               array_out=False):
     """Compute power or energy acoss a frequency band, and its peak frequency.
     Power is estimated using the mid-point rectangle rule. Input can be 
     ChanTime or ChanFreq.
@@ -361,13 +381,6 @@ def band_power(data, freq, scaling='power', n_fft=None, array_out=False):
         power = zeros((data.number_of('chan')[0], 1))
         peakf = zeros((data.number_of('chan')[0], 1))
 
-    if 'power' == scaling:
-        detrend = 'linear'
-    elif 'energy' == scaling:
-        detrend = None
-    else:
-        raise ValueError("scaling must be 'power' or 'energy'")
-
     if isinstance(data, ChanFreq):
         Sxx = data
     elif isinstance(data, ChanTime):
@@ -375,6 +388,12 @@ def band_power(data, freq, scaling='power', n_fft=None, array_out=False):
     else:
         raise ValueError('Invalid data type')
     
+    if detrend is None:
+        if 'power' == scaling:
+            detrend = 'linear'
+        elif 'energy' == scaling:
+            detrend = None
+    
     sf = Sxx.axis['freq'][0]
     f_res = sf[1] - sf[0] # frequency resolution
     
